## Game files

### From game folder

| Format extension | Count | Is game specific                     | Is binary                            | Info                       |
|------------------|-------|--------------------------------------|--------------------------------------|----------------------------|
| `.qvm`           | 997   | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> | [Docs](docs/format_qvm.md) |
| `.wav`           | 394   | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.dat` (graph)   | 300   | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.res`           | 92    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.tex`           | 26    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.dat` (mtp)     | 17    | <span style="color:green">Yes</span> | <span style="color:red">No </span>   |                            |
| `.mtp`           | 17    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.bit`           | 14    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.cmd`           | 14    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.ctr`           | 14    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.lmp`           | 14    | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.hmp`           | 6     | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.rtf`           | 6     | <span style="color:red">No </span>   | <span style="color:red">No </span>   |                            |
| `.txt`           | 6     | <span style="color:red">No </span>   | <span style="color:red">No </span>   |                            |
| `.iff`           | 6     | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |
| `.url`           | 5     | <span style="color:red">No </span>   | <span style="color:red">No </span>   |                            |
| `.avi`           | 5     | <span style="color:red">No </span>   | <span style="color:green">Yes</span> |                            |
| `.AFP`           | 3     | <span style="color:red">No </span>   | <span style="color:red">No </span>   |                            |
| `.exe`           | 2     | <span style="color:red">No </span>   | <span style="color:green">Yes</span> |                            |
| `.fnt`           | 2     | <span style="color:green">Yes</span> | <span style="color:green">Yes</span> |                            |

### From .res files

| Format extension | Count | Is game specific                     | Is binary                             | Info |
|------------------|-------|--------------------------------------|---------------------------------------|------|
| `.olm`           | 25337 | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.tex`           | 7199  | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.mef`           | 6794  | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.wav`           | 346   | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.spr`           | 158   | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.fnt`           | 9     | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
| `.pic`           | 5     | <span style="color:green">Yes</span> | <span style="color:green">Yes</span>  |      |
